<?php
/**
 * Ecommerce Center functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Ecommerce Center
 */

function ecommerce_center_enqueue_styles() {
    $parentcss = 'ecommerce-zone-style';
    $theme = wp_get_theme(); wp_enqueue_style( $parentcss, get_template_directory_uri() . '/style.css', array(), $theme->parent()->get('Version'));
    wp_enqueue_style( 'ecommerce-center-style', get_stylesheet_uri(), array( $parentcss ), $theme->get('Version'));
}

add_action( 'wp_enqueue_scripts', 'ecommerce_center_enqueue_styles' );

/**
 * Enqueue theme color style.
 */
function ecommerce_center_theme_color() {

    $theme_color_css = '';
    $ecommerce_zone_theme_color = get_theme_mod('ecommerce_zone_theme_color');

    $theme_color_css = '
        span.cart-value,#button,.main-navigation .menu > li > a:hover,.pro-button a:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,.woocommerce ul.products li.product .onsale, .woocommerce span.onsale,.woocommerce .woocommerce-ordering select,.woocommerce-account .woocommerce-MyAccount-navigation ul li,.wp-block-button__link,.comment-respond input#submit{
            background: '.esc_attr($ecommerce_zone_theme_color).';
        }
        {
            color: '.esc_attr($ecommerce_zone_theme_color).';
        }
        .wp-block-quote, .wp-block-quote:not(.is-large):not(.is-style-large), .wp-block-pullquote{
            border-color: '.esc_attr($ecommerce_zone_theme_color).' !important;
        }
        .serv-box:hover{
            background: transparent;
        }
    ';
    wp_add_inline_style( 'ecommerce-center-style',$theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'ecommerce_center_theme_color' );

function ecommerce_center_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

function ecommerce_center_customize_register($wp_customize){

	// Blog Section
    $wp_customize->add_section( 'ecommerce_center_blog_section' , array(
        'title'      => __( 'Blog Settings', 'ecommerce-center' ),
        'priority'   => null
    ) );

    $wp_customize->add_setting('ecommerce_center_blog_section_title',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    )); 
    $wp_customize->add_control('ecommerce_center_blog_section_title',array(
        'label' => esc_html__('Section Title','ecommerce-center'),
        'section' => 'ecommerce_center_blog_section',
        'setting' => 'ecommerce_center_blog_section_title',
        'type'  => 'text'
    ));

    $categories = get_categories();
    $cat_post = array();
    $cat_post[]= 'select';
    $i = 0; 
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cat_post[$category->slug] = $category->name;
    }

    $wp_customize->add_setting('ecommerce_center_blog',array(
        'default'   => 'select',
        'sanitize_callback' => 'ecommerce_zone_sanitize_choices',
    ));
    $wp_customize->add_control('ecommerce_center_blog',array(
        'type'    => 'select',
        'choices' => $cat_post,
        'label' => __('Select Category to display Services','ecommerce-center'),
        'section' => 'ecommerce_center_blog_section',
    ));
}
add_action('customize_register', 'ecommerce_center_customize_register');